package WWW::Tumblr::Tagged;

1;

=pod

=head1 NAME

WWW::Tumblr::Tagged

=head1 SYNOPSIS

  # this module doesn't really exist - to use tagged methods
  # you can do something like:
  
  my $tagged = $tumblr->tagged( tag => 'perl' );

  # and that's it. There's nothing really inside WWW::Tumblr::Tagged

=head1 BUGS

Please refer to L<WWW::Tumblr>.

=head1 AUTHOR(S)

The same folks as L<WWW::Tumblr>.

=head1 SEE ALSO

L<WWW::Tumblr>, L<WWW::Tumblr::ResponseError>.

=head1 COPYRIGHT and LICENSE

Same as L<WWW::Tumblr>.

=cut

